#
# spec file for package spice-up
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           spice-up
Version:        1.3.2
Release:        lp150.1.3
Summary:        Desktop presentation application
License:        GPL-3.0
Group:          Productivity/Multimedia/Video/Players
Url:            https://launchpad.net/spice-up
Source:         https://github.com/Philip-Scott/Spice-up/archive/%{version}.tar.gz#/Spice-up-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite) >= 0.3
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.18.0
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libevdev)
Requires(post):    shared-mime-info
Requires(postun):  shared-mime-info
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
Spice-up is a desktop presentation application
based upon SpiceOfDesign's presentation concept.

%lang_package

%prep
%setup -q -n Spice-up-%{version}

%build
%cmake \
    -DGSETTINGS_COMPILE=OFF
    
# remove smp_mflags to avoid compilation errors
make -j1 V=1

%install
%cmake_install
mkdir -p %{buildroot}%{_datadir}/appdata
mv %{buildroot}%{_datadir}/{metainfo,appdata}/com.github.philip-scott.%{name}.appdata.xml
%find_lang com.github.philip-scott.spice-up %{name}.lang
%fdupes %{buildroot}%{_datadir}

%post
%mime_database_post
%icon_theme_cache_post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%mime_database_postun
%icon_theme_cache_postun
%desktop_database_postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc COPYING README.md
%{_bindir}/com.github.philip-scott.spice-up
%{_datadir}/com.github.philip-scott.spice-up/
%{_datadir}/applications/*.%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*%{name}.??g
%{_datadir}/icons/hicolor/*/mimetypes/*spiceup.??g
%{_datadir}/glib-2.0/schemas/*.%{name}.gschema.xml
%{_datadir}/appdata/*.%{name}.appdata.xml
%{_datadir}/mime/packages/*%{name}.mime.xml
%dir %{_datadir}/appdata

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Fri Feb 23 2018 avvissu@yandex.by
- Update to 1.3.2:
  * Use elementary color palette with the icons
  * Selected style on Gradient Editor Nubs
  * Keep track of previous selected step
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * add custom color picker icons
* Fri Feb  9 2018 avvissu@yandex.by
- Update to 1.3.0:
  * Prevent accidental background image changes
  * Disable notifications while presenting
  * Font style with markup (#193)
  * Add new tooltips
  * Make UI icons symbolic
  * Add gradient palette
  * Reset canceled color from picker properly
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * Updated screenshot
  * Color picker makeover (#189)
  * TextBar.vala: Make font-style EntryCombo uneditable (#188)
  * Search fonts (#186)
  * Fix font picker styles on Gtk3.22
* Sat Jan  6 2018 avvissu@yandex.by
- Update to 1.2.1:
  * Don't override the system CFLAGS
  * Fix appdata validations
  * More image validations
  * Add Screenshot4.png
  * Clickable next-preview
  * Gtk 3.22 fixes
  * Fix small typo.
  * Connect end of presentation slide
  * Refactored Ligrary and Template view into one
  * Add missing element to empty slide json
  * Always open PresenterView with -d
  * Add the Presentation view
  * Add Slideshow Controller
  * Use SlideWidget
  * Create and use SlideWidget
  * Load edit and save slide notes
  * End of presentation slide added
  * Prevent loading a null slide preview
  * Use Gdk.Cursor.from_name
  * PresenterWindow tweaks
* Sun Nov 19 2017 avvissu@yandex.by
- Remove smp_mflags to avoid compilation errors
* Sat Nov  4 2017 avvissu@yandex.by
- Update to 1.1.0:
  * Add images on Drag & Drop
  * Update README.md
  * Update com.github.philip-scott.spice-up.appdata.xml
* Wed Oct 18 2017 avvissu@yandex.by
- Update to 1.0.1:
  * Create pull_request_template.md
  * Fix screenshot
  * Catch NULL Documents folder
  * Allow future ViewerFiles to be open
  * Allow future viewer files to be openable
  * Scroll presentation with PgUp and PgDn
  * Reset ImageID when a new presentation loads
  * Lazy load slides
  * Text vertical alignment (#158)
  * Animate going back to the welcome screen
  * Change order of text toolbar
  * Move justification items to popover
* Mon Sep 18 2017 avvissu@yandex.by
- Update to 1.0.0:
  * Delete empty files
  * Saving a presentation with no content causes a crash on load
* Tue Sep 12 2017 avvissu@yandex.by
- Update to 0.9.0:
  * Update README.md
  * Add another screenshot
  * Update appdata & new screenshot
  * Roundness scale text now reads better
  * Allow for setting opacity on Text and Color items
  * Fix: Double clicking would sometimes unselect the item
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * Images: Add a way to replace them
  * Modify template format
  * New slide button not focusable
  * Put previous values on new canvas
  * New Presentation templates
  * Skip tests in Houston
  * Disable testing on displayless server
  * Update com.github.philip-scott.spice-up.appdata.xml
  * Update screenshots
  * Updated 128px icon
  * Add undo & redo shortcuts
  * Gtk 3.22 support (#138)
  * Slide list on click response
- Add a package with translations
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 0.8.1:
  * New icon & Add icon for different sizes (#134)
* Fri Jul 21 2017 avvissu@yandex.by
- Update to 0.8.0:
  * Move stylesheet to GResource
  * multi-threading library loading
  * Open file location
  * Don't ask where to save before you can use the app
  * Edit presentation properties from the browser
  * Revamped welcome screen
  * Copy, Cut and Paste from your keyboard
  * Add Roundness tooltip
  * Update last file when opening from Files
  * Moved main stylesheet & fix modebutton checked
  * ShapeItem: Set border radius
  * Update preview when adding/removing items
  * Exit presentation mode with Esc
  * Better raw image handling
  * Text to base64, fix crashes with special characters
  * Refactor image handling
* Sat Jul  1 2017 avvissu@yandex.by
- Update to 0.6.5:
  * Correcting MimeType in .desktop file.
  * misc code cleanups
  * Fix text undo
  * Make sure canvas items get freed from memory
  * Update first presentation
  * Add a way to launch an image editor
  * monitor file changes
  * Load images from file
  * Update com.github.philip-scott.spice-up.appdata.xml
  * Merge pull request #126 from danrabbit/patch-1
  * Update README.md
  * Bump version number
  * Clone button added
  * Readme reloaded (#125)
  * Add link to AppCenter
  * Style changes
  * Style the color popover
  * Better color palette
  * Added mimetype icon
  * Updated testing presentation
* Tue Jun 13 2017 jengelh@inai.de
- Ensure neutrality of description.
* Sat May 27 2017 avvissu@yandex.by
- Update to 0.5.5:
  * Move patterns to gresource
  * Fix: Justification not working correctly on one line
  * Added file checking for missing patterns, and pointed them to
    the right direction
  * Fixed: text on slides flashes when the window is resized
  * Fix delete & re-add icon to CMAKE
  * Fix: added .spice to all files
  * Update GResources.cmake
  * Use RDNN everywhere
  * Updated Screenshot
  * Don't constraint movement with fix_position
  * CommonBar: Changed tooltips
  * Save file with app's extension
  * CanvasItem: Min size Part2
  * CanvasItems: Min size
* Sat May 20 2017 avvissu@yandex.by
- Update to 0.4.6:
  * Use backspace for item deletion
  * stylize the slide list
  * Make new items use the properties of the previous one
  * remove margins on drag icon
  * Add non-standard icons to a gresource
  * Update CanvasItem.vala
* Mon May 15 2017 avvissu@yandex.by
- Update to 0.4.3:
  * Added configuration dialog
  * Merge branch 'master' into Controller-configuration
  * Add the defaults to controller config
  * Add title to controller dialog
  * Make sure to show all
* Sun May  7 2017 avvissu@yandex.by
- Update to 0.4.2:
  * Fixed: Can edit slides while presenting
  * Fixed: Fix shortcuts breaking typing
  * All text should now be translatable
  * Move though presentation mode using your keyboard
  * Use a JoyCon to control your slides in presentation mode
  * Fixed: Crashes if clicked when no slide was selected
  * Fixed: No gradient applied if there's no direction chosen
* Wed May  3 2017 avvissu@yandex.by
- Update to 0.3.6:
  * Open-with support for .spice files
  * A better looking icon
  * Previews are now stored on the file instead of re-making the canvas
- Add MIME databases
* Mon May  1 2017 avvissu@yandex.by
- Update to 0.3.5:
  * Update the Screenshot and the brand colors
  * Add appcenter brand colors & move appdata location
  * Trying to work around liftoff
  * Now with hopefully more screenshots
- Drop patches (fixed):
  * desktop.patch
  * appdata.patch
  * license.patch
* Sun Feb 26 2017 mailaender@opensuse.org
- initial packaging of version 0.2.7
